@@ -7,8 +7,7 @@ class ParseSessionException(Exception):
         message: str = "Wrong session format; session format is like 'builds/<build name>/test_sessions/<test session id>'.",
     ):
         self.session = session
-        self.message = "{message}: {session}".format(
-            message=message, session=self.session)
+        self.message = "{message}: {session}".format(message=message, session=self.session)
         super().__init__(self.message)
 
 
@@ -19,6 +18,5 @@ class InvalidJUnitXMLException(Exception):
         message: str = "Invalid JUnit XML file format",
     ):
         self.filename = filename
-        self.message = "{message}: {filename}".format(
-            message=message, filename=self.filename)
+        self.message = "{message}: {filename}".format(message=message, filename=self.filename)
         super().__init__(self.message)
